summaryrefslogtreecommitdiffstats
path: root/test
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2010-11-06 23:13:39 +0100
committerSven Gothel <[email protected]>2010-11-06 23:13:39 +0100
commit6f2d046c8d532db94f6af5003e341104d5bf4aff (patch)
tree723c31b8f9c1097ae48486acbf68e4e06fab2517 /test
parentec6d61f4597af32c22319c4bda3c9dd9ab80bf25 (diff)
Renamed com.sun.gluegen -> com.jogamp.gluegen
Diffstat (limited to 'test')
-rw-r--r--test/junit/com/sun/gluegen/BasicProcAddressEmitterTest.java6
-rw-r--r--test/junit/com/sun/gluegen/BasicTest.java4
-rw-r--r--test/junit/com/sun/gluegen/BuildUtil.java6
-rw-r--r--test/junit/com/sun/gluegen/PCPPTest.java4
-rw-r--r--test/junit/com/sun/gluegen/StructAccessorTest.java8
-rw-r--r--test/junit/com/sun/gluegen/StructValidator.java4
-rw-r--r--test/junit/com/sun/gluegen/build.xml4
7 files changed, 19 insertions, 17 deletions
diff --git a/test/junit/com/sun/gluegen/BasicProcAddressEmitterTest.java b/test/junit/com/sun/gluegen/BasicProcAddressEmitterTest.java
index 5b32916..10156f9 100644
--- a/test/junit/com/sun/gluegen/BasicProcAddressEmitterTest.java
+++ b/test/junit/com/sun/gluegen/BasicProcAddressEmitterTest.java
@@ -26,16 +26,16 @@
* or implied, of JogAmp Community.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
-import com.sun.gluegen.procaddress.ProcAddressEmitter;
+import com.jogamp.gluegen.procaddress.ProcAddressEmitter;
import java.lang.reflect.Field;
import java.util.HashSet;
import java.util.Set;
import org.junit.AfterClass;
import org.junit.Test;
import static java.util.Arrays.*;
-import static com.sun.gluegen.BuildUtil.*;
+import static com.jogamp.gluegen.BuildUtil.*;
import static org.junit.Assert.*;
/**
diff --git a/test/junit/com/sun/gluegen/BasicTest.java b/test/junit/com/sun/gluegen/BasicTest.java
index 42096db..38bb7f9 100644
--- a/test/junit/com/sun/gluegen/BasicTest.java
+++ b/test/junit/com/sun/gluegen/BasicTest.java
@@ -26,7 +26,7 @@
* or implied, of JogAmp Community.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import com.jogamp.common.nio.Buffers;
import com.jogamp.common.nio.PointerBuffer;
@@ -38,7 +38,7 @@ import org.junit.AfterClass;
import org.junit.Test;
import static org.junit.Assert.*;
import static java.lang.System.*;
-import static com.sun.gluegen.BuildUtil.*;
+import static com.jogamp.gluegen.BuildUtil.*;
/**
*
diff --git a/test/junit/com/sun/gluegen/BuildUtil.java b/test/junit/com/sun/gluegen/BuildUtil.java
index 76de30f..ce88ba2 100644
--- a/test/junit/com/sun/gluegen/BuildUtil.java
+++ b/test/junit/com/sun/gluegen/BuildUtil.java
@@ -26,8 +26,10 @@
* or implied, of JogAmp Community.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
+import com.jogamp.gluegen.JavaEmitter;
+import com.jogamp.gluegen.GlueGen;
import java.io.File;
import java.net.URISyntaxException;
import org.apache.tools.ant.DefaultLogger;
@@ -71,7 +73,7 @@ public final class BuildUtil {
throw new RuntimeException("can not determine gluegen root", ex);
}
- path = gluegenRoot + "/test/junit/com/sun/gluegen";
+ path = gluegenRoot + "/test/junit/com/jogamp/gluegen";
testOutput = gluegenRoot + "/" + rootrel_build + "/test";
out.println("path: "+path);
diff --git a/test/junit/com/sun/gluegen/PCPPTest.java b/test/junit/com/sun/gluegen/PCPPTest.java
index deea0d8..c1f12ab 100644
--- a/test/junit/com/sun/gluegen/PCPPTest.java
+++ b/test/junit/com/sun/gluegen/PCPPTest.java
@@ -26,9 +26,9 @@
* or implied, of JogAmp Community.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
-import com.sun.gluegen.pcpp.PCPP;
+import com.jogamp.gluegen.pcpp.PCPP;
import java.io.BufferedReader;
import java.io.ByteArrayOutputStream;
import java.io.FileNotFoundException;
diff --git a/test/junit/com/sun/gluegen/StructAccessorTest.java b/test/junit/com/sun/gluegen/StructAccessorTest.java
index 9c50673..4d1bffd 100644
--- a/test/junit/com/sun/gluegen/StructAccessorTest.java
+++ b/test/junit/com/sun/gluegen/StructAccessorTest.java
@@ -26,7 +26,7 @@
* or implied, of JogAmp Community.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.io.File;
import java.io.IOException;
@@ -45,7 +45,7 @@ import junit.framework.Assert;
import org.junit.AfterClass;
import org.junit.Test;
import static java.lang.System.*;
-import static com.sun.gluegen.BuildUtil.*;
+import static com.jogamp.gluegen.BuildUtil.*;
/**
*
@@ -73,11 +73,11 @@ public class StructAccessorTest {
public void validateGeneratedStructs() throws IOException, NoSuchMethodException, ClassNotFoundException, IllegalAccessException, InvocationTargetException {
// compile testcase
- String source = gluegenRoot + "/test/junit/com/sun/gluegen/StructValidator.java";
+ String source = gluegenRoot + "/test/junit/com/jogamp/gluegen/StructValidator.java";
compile(new File(source), testOutput + "/build/classes");
// invoke test
- Class<?> test = Class.forName("com.sun.gluegen.StructValidator");
+ Class<?> test = Class.forName("com.jogamp.gluegen.StructValidator");
test.getDeclaredMethod("validate").invoke(null);
}
diff --git a/test/junit/com/sun/gluegen/build.xml b/test/junit/com/sun/gluegen/build.xml
index 6622e0c..95617be 100644
--- a/test/junit/com/sun/gluegen/build.xml
+++ b/test/junit/com/sun/gluegen/build.xml
@@ -64,12 +64,12 @@
rtti="false"
failonerror="true">
- <fileset dir="${gluegen.root}/test/junit/com/sun/gluegen" includes="*.c"/>
+ <fileset dir="${gluegen.root}/test/junit/com/jogamp/gluegen" includes="*.c"/>
<compiler extends="${compiler.cfg.id}" >
<includepath path="${java.includes.dir}"/>
<includepath path="${java.includes.dir.platform}"/>
- <includepath path="${gluegen.root}/test/junit/com/sun/gluegen"/>
+ <includepath path="${gluegen.root}/test/junit/com/jogamp/gluegen"/>
</compiler>
<linker extends="${linker.cfg.id}">
diff --git a/test/junit/com/sun/gluegen/StructValidator.java b/test/junit/com/sun/gluegen/StructValidator.java
index 9bdcbae..b6eb426 100644
--- a/test/junit/com/sun/gluegen/StructValidator.java
+++ b/test/junit/com/sun/gluegen/StructValidator.java
@@ -26,7 +26,7 @@
* or implied, of JogAmp Community.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.lang.reflect.InvocationTargetException;
import org.junit.Ignore;
@@ -34,7 +34,7 @@ import org.junit.Ignore;
import static org.junit.Assert.*;
/**
* this file will not compile unless {@link com.sun.gluegen.StructAccessorTest} has been run.
* @author Michael Bien
*/
@Ignore
@@ -34,7 +34,7 @@ import org.junit.Ignore;
import static org.junit.Assert.*;
/**
- * this file will not compile unless {@link com.sun.gluegen.StructAccessorTest} has been run.
+ * this file will not compile unless {@link com.jogamp.gluegen.StructAccessorTest} has been run.
* @author Michael Bien
*/